/* Message list header time simple parser.
   Copyright (C) 2019 Free Software Foundation, Inc.
   Written by Markéta Calábková <mcalabkova@suse.cz>, 2019.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include <string.h>
#include <time.h>

#include "xalloc.h"
#include "error.h"
#include "xerror.h"
#include "xvasprintf.h"

#include "msgl-header.h"
#include <stdlib.h>
#include <stdio.h>
#include "gettext.h"

#include "msgl-age.h"

#define _(str) gettext (str)

void
msgdomain_sort_by_ages (msgdomain_list_ty **mdlps, size_t nfiles)
{
	qsort (mdlps, nfiles, sizeof(msgdomain_list_ty*), msgdomain_compare_ages);
}

int
msgdomain_compare_ages (const void * p1, const void * p2)
{
  if (difftime((*(msgdomain_list_ty **)p2)->msgage, (*(msgdomain_list_ty **)p1)->msgage) > 0)
    return 1;
  else
    return 0;
}

void
msgdomain_read_ages (msgdomain_list_ty *mdlp)
{
  time_t times[mdlp->nitems];
  const char * field = "PO-Revision-Date:";
  char * where;

  for (int i = 0; i < mdlp->nitems; i++)
    {
      message_list_ty *mlp = mdlp->item[i]->messages;

      message_list_read_header_field (mlp, field, &where);
    }
  struct tm tmptm;
  char *trail;
  memset (&tmptm, 0, sizeof(struct tm));
  if ((trail = strptime (where, "%Y-%m-%d %H:%M:%S%z", &tmptm)) != NULL)
    mdlp->msgage = mktime (&tmptm);
  else if ((trail = strptime (where, "%Y-%m-%d %H:%M:%S", &tmptm)) != NULL)
    mdlp->msgage = mktime (&tmptm);
  else if ((trail = strptime (where, "%Y-%m-%d %H:%M%z", &tmptm)) != NULL)
    mdlp->msgage = mktime (&tmptm);
  else if ((trail = strptime (where, "%Y-%m-%d %H:%M", &tmptm)) != NULL)
    mdlp->msgage = mktime (&tmptm);
  else
  {
    /* There is probably no creation date. Assign 0 and throw warning. */
    mdlp->msgage = 0;
    multiline_warning (xasprintf (_("warning: ")),
    xasprintf (_("\
PO-Revision-Date has no or invalid value, assuming it is old.\n\
")));
    return;
  }
  if ((*trail != '\n') && (*trail != '\0'))
    multiline_warning (xasprintf (_("warning: ")),
    xasprintf (_("\
Unknown trailing characters after PO-Revision-Date, ignoring.\n\
")));
}



